@@ -5,10 +5,16 @@ use warnings;
 
 use Dancer ':script';
 use Net::DNS;
-use AnyEvent::DNS::EtcHosts;
 use AnyEvent::DNS;
 use NetAddr::IP::Lite ':lower';
 
+# AE::DNS::EtcHosts only works for A/AAAA/SRV, but we want PTR.
+# this loads+parses /etc/hosts file using AE. dirty hack.
+use AnyEvent::Socket 'format_address';
+use AnyEvent::DNS::EtcHosts;
+AnyEvent::DNS::EtcHosts::_load_hosts_unless(sub{},AE::cv);
+no AnyEvent::DNS::EtcHosts; # unimport
+
 use base 'Exporter';
 our @EXPORT = ();
 our @EXPORT_OK = qw/
@@ -97,16 +103,29 @@ addresses which resolved.
 
 sub hostnames_resolve_async {
   my $ips = shift;
-
   my $resolver = AnyEvent::DNS->new();
-    
+
+  my %HOSTS = ();
+  $HOSTS{$_} = [ map { [ $_ ? (format_address $_->[0]) : '' ] }
+                     @{$AnyEvent::DNS::EtcHosts::HOSTS{$_}} ]
+    for keys %AnyEvent::DNS::EtcHosts::HOSTS;
+
   # Set up the condvar
   my $done = AE::cv;
   $done->begin( sub { shift->send } );
 
-  foreach my $hash_ref (@$ips) {
+  IP: foreach my $hash_ref (@$ips) {
     my $ip = $hash_ref->{'ip'} || $hash_ref->{'alias'};
-    next if no_resolve($ip);
+    next IP if no_resolve($ip);
+
+    # check /etc/hosts file and short-circuit if found
+    foreach my $name (reverse sort keys %HOSTS) {
+        if ($HOSTS{$name}->[0]->[0] eq $ip) {
+            $hash_ref->{'dns'} = $name;
+            next IP;
+        }
+    }
+
     $done->begin;
     AnyEvent::DNS::reverse_lookup $ip,
             sub { $hash_ref->{'dns'} = shift; $done->end; };
